@@ -85,6 +85,7 @@ import com.openexchange.threadpool.Task;
 import com.openexchange.threadpool.ThreadPoolService;
 import com.openexchange.threadpool.ThreadPools;
 import com.openexchange.unifiedinbox.copy.UnifiedINBOXMessageCopier;
+import com.openexchange.unifiedinbox.dataobjects.UnifiedMailMessage;
 import com.openexchange.unifiedinbox.services.UnifiedINBOXServiceRegistry;
 import com.openexchange.unifiedinbox.utility.LoggingCallable;
 import com.openexchange.unifiedinbox.utility.TrackingCompletionService;
@@ -305,8 +306,8 @@ public final class UnifiedINBOXMessageStorage extends MailMessageStorage {
             close = true;
             // Get messages
             final MailMessage[] mails = mailAccess.getMessageStorage().getMessages(fa.getFullname(), mailIds, fields);
-            for (int i = 0; i < mails.length; i++) {
-                mails[i].setFolder(fullname);
+            for (final MailMessage mail : mails) {
+                mail.setFolder(fullname);
             }
             return mails;
         } finally {
@@ -328,10 +329,11 @@ public final class UnifiedINBOXMessageStorage extends MailMessageStorage {
             try {
                 mailAccess.connect();
                 close = true;
-                final MailMessage mail = mailAccess.getMessageStorage().getMessage(uid.getFullname(), uid.getId(), markSeen);
+                MailMessage mail = mailAccess.getMessageStorage().getMessage(uid.getFullname(), uid.getId(), markSeen);
                 if (null == mail) {
                     return null;
                 }
+                mail = new UnifiedMailMessage(mail);
                 mail.setMailId(mailId);
                 mail.setFolder(fullname);
                 mail.loadContent();
@@ -375,8 +377,7 @@ public final class UnifiedINBOXMessageStorage extends MailMessageStorage {
                     UnifiedINBOXServiceRegistry.getServiceRegistry().getService(MailAccountStorageService.class, true);
                 final MailAccount[] tmp = storageService.getUserMailAccounts(user, cid);
                 final List<MailAccount> l = new ArrayList<MailAccount>(tmp.length);
-                for (int i = 0; i < tmp.length; i++) {
-                    final MailAccount mailAccount = tmp[i];
+                for (final MailAccount mailAccount : tmp) {
                     if (access.getAccountId() != mailAccount.getId() && mailAccount.isUnifiedINBOXEnabled()) {
                         l.add(mailAccount);
                     }
@@ -416,11 +417,11 @@ public final class UnifiedINBOXMessageStorage extends MailMessageStorage {
                                 mailAccess.getMessageStorage().searchMessages(fn, indexRange, sortField, order, searchTerm, fields);
                             final List<MailMessage> messages = new ArrayList<MailMessage>(accountMails.length);
                             final UnifiedINBOXUID helper = new UnifiedINBOXUID();
-                            for (int i = 0; i < accountMails.length; i++) {
-                                final MailMessage accountMail = accountMails[i];
-                                accountMail.setMailId(helper.setUID(mailAccount.getId(), fn, accountMail.getMailId()).toString());
-                                accountMail.setFolder(fullname);
-                                messages.add(accountMail);
+                            for (final MailMessage accountMail : accountMails) {
+                                final UnifiedMailMessage umm = new UnifiedMailMessage(accountMail);
+                                umm.setMailId(helper.setUID(mailAccount.getId(), fn, accountMail.getMailId()).toString());
+                                umm.setFolder(fullname);
+                                messages.add(umm);
                             }
                             return messages;
                         } finally {
@@ -459,8 +460,8 @@ public final class UnifiedINBOXMessageStorage extends MailMessageStorage {
             // Get account's messages
             final MailMessage[] mails =
                 mailAccess.getMessageStorage().searchMessages(fa.getFullname(), indexRange, sortField, order, searchTerm, fields);
-            for (int i = 0; i < mails.length; i++) {
-                mails[i].setFolder(fullname);
+            for (final MailMessage mail : mails) {
+                mail.setFolder(fullname);
             }
             return mails;
         } finally {
@@ -482,8 +483,7 @@ public final class UnifiedINBOXMessageStorage extends MailMessageStorage {
                     UnifiedINBOXServiceRegistry.getServiceRegistry().getService(MailAccountStorageService.class, true);
                 final MailAccount[] tmp = storageService.getUserMailAccounts(user, cid);
                 final List<MailAccount> l = new ArrayList<MailAccount>(tmp.length);
-                for (int i = 0; i < tmp.length; i++) {
-                    final MailAccount mailAccount = tmp[i];
+                for (final MailAccount mailAccount : tmp) {
                     if (access.getAccountId() != mailAccount.getId() && mailAccount.isUnifiedINBOXEnabled()) {
                         l.add(mailAccount);
                     }
@@ -522,11 +522,11 @@ public final class UnifiedINBOXMessageStorage extends MailMessageStorage {
                                 mailAccess.getMessageStorage().getUnreadMessages(fn, sortField, order, fields, limit);
                             final UnifiedINBOXUID helper = new UnifiedINBOXUID();
                             final List<MailMessage> messages = new ArrayList<MailMessage>(accountMails.length);
-                            for (int i = 0; i < accountMails.length; i++) {
-                                final MailMessage accountMail = accountMails[i];
-                                accountMail.setMailId(helper.setUID(mailAccount.getId(), fn, accountMail.getMailId()).toString());
-                                accountMail.setFolder(fullname);
-                                messages.add(accountMail);
+                            for (final MailMessage accountMail : accountMails) {
+                                final UnifiedMailMessage umm = new UnifiedMailMessage(accountMail);
+                                umm.setMailId(helper.setUID(mailAccount.getId(), fn, accountMail.getMailId()).toString());
+                                umm.setFolder(fullname);
+                                messages.add(umm);
                             }
                             return messages;
                         } finally {
@@ -564,8 +564,8 @@ public final class UnifiedINBOXMessageStorage extends MailMessageStorage {
             close = true;
             // Get account's messages
             final MailMessage[] mails = mailAccess.getMessageStorage().getUnreadMessages(fa.getFullname(), sortField, order, fields, limit);
-            for (int i = 0; i < mails.length; i++) {
-                mails[i].setFolder(fullname);
+            for (final MailMessage mail : mails) {
+                mail.setFolder(fullname);
             }
             return mails;
         } finally {
@@ -850,21 +850,20 @@ public final class UnifiedINBOXMessageStorage extends MailMessageStorage {
 
     private static void insertMessage(final String[] mailIds, final MailMessage[] toFill, final int accountId, final String folder, final MailMessage[] mails, final String uiFullname) {
         final UnifiedINBOXUID helper = new UnifiedINBOXUID();
-        for (int k = 0; k < mails.length; k++) {
-            final MailMessage mail = mails[k];
+        for (final MailMessage mail : mails) {
             if (null != mail) {
                 final String lookFor = helper.setUID(accountId, folder, mail.getMailId()).toString();
                 int pos = -1;
                 for (int l = 0; l < mailIds.length && pos == -1; l++) {
-                    final String mailId = mailIds[l];
-                    if (lookFor.equals(mailId)) {
+                    if (lookFor.equals(mailIds[l])) {
                         pos = l;
                     }
                 }
                 if (pos != -1) {
-                    toFill[pos] = mail;
-                    mail.setMailId(mailIds[pos]);
-                    mail.setFolder(uiFullname);
+                    final UnifiedMailMessage umm = new UnifiedMailMessage(mail);
+                    toFill[pos] = umm;
+                    umm.setMailId(mailIds[pos]);
+                    umm.setFolder(uiFullname);
                 }
             }
         }
