@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -143,7 +143,7 @@ public final class UnifiedINBOXMessageCopier {
                 callable = new KF2KFCallable(sourceFolder, destFolder, fast, move, retval, tmp.getAccountId(), session);
                 callableMap.put(accountId, callable);
             }
-            callable.addIdAndIndex(tmp.getId(), Integer.valueOf(i));
+            callable.addIdAndIndex(tmp.getId(), i);
         }
         // Perform callables
         final ThreadPoolService threadPoolService = UnifiedINBOXServiceRegistry.getServiceRegistry().getService(ThreadPoolService.class);
@@ -190,7 +190,7 @@ public final class UnifiedINBOXMessageCopier {
                     callable = new KF2AFEqualCallable(sourceFolder, destFullname, fast, move, retval, tmp.getAccountId(), session);
                     callableMap.put(accountId, callable);
                 }
-                callable.addIdAndIndex(tmp.getId(), Integer.valueOf(i));
+                callable.addIdAndIndex(tmp.getId(), i);
             } else {
                 // Accounts differ
                 KF2AFDifferCallable callable = otherCallableMap.get(accountId);
@@ -198,7 +198,7 @@ public final class UnifiedINBOXMessageCopier {
                     callable = new KF2AFDifferCallable(tmp.getAccountId(), destAccountId, destFullname, fast, move, retval, session);
                     otherCallableMap.put(accountId, callable);
                 }
-                callable.addIdAndFullnameAndIndex(tmp.getId(), tmp.getFullname(), Integer.valueOf(i));
+                callable.addIdAndFullnameAndIndex(tmp.getId(), tmp.getFullname(), i);
             }
         }
         // Perform callables
